@@ -11,25 +11,30 @@ from vortex.PayloadEnvelope import PayloadEnvelope
 from vortex.PayloadResponse import PayloadResponse
 from vortex.VortexABC import SendVortexMsgResponseCallable
 from vortex.VortexFactory import VortexFactory
-from vortex.handler.TupleActionProcessor import TupleActionProcessor, \
-    TupleActionProcessorDelegateABC
+from vortex.handler.TupleActionProcessor import (
+    TupleActionProcessor,
+    TupleActionProcessorDelegateABC,
+)
 
 logger = logging.getLogger(__name__)
 
 
 class TupleActionProcessorProxy:
-    """ Tuple Data Observable Proxy Handler
+    """Tuple Data Observable Proxy Handler
 
     This class proxies the TupleActions onto another destination, giving the ability
     to pass through one services into another. EG, from a client facing python service
     to a server backend.
     """
 
-    def __init__(self, tupleActionProcessorName,
-                 proxyToVortexName: str,
-                 additionalFilt=None,
-                 acceptOnlyFromVortex: Optional[Union[str,tuple]] = None) -> None:
-        """ Constructor
+    def __init__(
+        self,
+        tupleActionProcessorName,
+        proxyToVortexName: str,
+        additionalFilt=None,
+        acceptOnlyFromVortex: Optional[Union[str, tuple]] = None,
+    ) -> None:
+        """Constructor
 
         :param tupleActionProcessorName: The name of this and the other action handler
         :param proxyToVortexName: The vortex dest name to proxy requests to
@@ -38,22 +43,27 @@ class TupleActionProcessorProxy:
         self._proxyToVortexName = proxyToVortexName
         self._delegateProcessor = TupleActionProcessor(
             tupleActionProcessorName=tupleActionProcessorName,
-            usedForProxy__=True
+            usedForProxy__=True,
         )
 
-        self._filt = dict(name=tupleActionProcessorName, key="tupleActionProcessorName")
+        self._filt = dict(
+            name=tupleActionProcessorName, key="tupleActionProcessorName"
+        )
 
         if additionalFilt:
             self._filt.update(additionalFilt)
 
-        self._endpoint = PayloadEndpoint(self._filt, self._process,
-                                         acceptOnlyFromVortex=acceptOnlyFromVortex)
+        self._endpoint = PayloadEndpoint(
+            self._filt, self._process, acceptOnlyFromVortex=acceptOnlyFromVortex
+        )
 
     def shutdown(self):
         self._endpoint.shutdown()
 
-    def setDelegate(self, tupleName: str, processor: TupleActionProcessorDelegateABC):
-        """ Add Tuple Action Processor Delegate
+    def setDelegate(
+        self, tupleName: str, processor: TupleActionProcessorDelegateABC
+    ):
+        """Add Tuple Action Processor Delegate
 
         :param tupleName: The tuple name to process actions for.
         :param processor: The processor to use for processing this tuple name.
@@ -62,8 +72,13 @@ class TupleActionProcessorProxy:
         self._delegateProcessor.setDelegate(tupleName, processor)
 
     @inlineCallbacks
-    def _process(self, payloadEnvelope: PayloadEnvelope, vortexName: str,
-                 sendResponse: SendVortexMsgResponseCallable, **kwargs) -> None:
+    def _process(
+        self,
+        payloadEnvelope: PayloadEnvelope,
+        vortexName: str,
+        sendResponse: SendVortexMsgResponseCallable,
+        **kwargs
+    ) -> None:
 
         # Ignore responses from the backend, these are handled by PayloadResponse
         if vortexName == self._proxyToVortexName:
@@ -71,29 +86,41 @@ class TupleActionProcessorProxy:
 
         # Shortcut the logic, so that we don't decode the payload unless we need to.
         if not self._delegateProcessor.delegateCount:
-            yield self._processForProxy(payloadEnvelope, vortexName, sendResponse)
+            yield self._processForProxy(
+                payloadEnvelope, vortexName, sendResponse
+            )
             return
 
         # If we have local processors, then work out if this tupleAction is meant for
         # the local processor.
         payload = yield payloadEnvelope.decodePayloadDefer()
 
-        assert len(payload.tuples) == 1, (
-                "TupleActionProcessor:%s Expected 1 tuples, received %s" % (
-            self._tupleActionProcessorName, len(payload.tuples)))
+        assert (
+            len(payload.tuples) == 1
+        ), "TupleActionProcessor:%s Expected 1 tuples, received %s" % (
+            self._tupleActionProcessorName,
+            len(payload.tuples),
+        )
 
         tupleAction = payload.tuples[0]
 
         if self._delegateProcessor.hasDelegate(tupleAction.tupleName()):
-            self._delegateProcessor._processTupleAction(payloadEnvelope.filt, sendResponse, tupleAction)
+            self._delegateProcessor._processTupleAction(
+                payloadEnvelope.filt, sendResponse, tupleAction
+            )
             return
 
         # Else, Just send it on to the delegate we're proxying for (the backend)
         yield self._processForProxy(payloadEnvelope, vortexName, sendResponse)
 
     @inlineCallbacks
-    def _processForProxy(self, payloadEnvelope: PayloadEnvelope, vortexName: str,
-                         sendResponse: SendVortexMsgResponseCallable, **kwargs):
+    def _processForProxy(
+        self,
+        payloadEnvelope: PayloadEnvelope,
+        vortexName: str,
+        sendResponse: SendVortexMsgResponseCallable,
+        **kwargs
+    ):
         # Keep a copy of the incoming filt, in case they are using PayloadResponse
         responseFilt = copy(payloadEnvelope.filt)
 
@@ -104,7 +131,7 @@ class TupleActionProcessorProxy:
             payloadEnvelope,
             timeout=PayloadResponse.TIMEOUT - 5,  # 5 seconds less
             resultCheck=False,
-            logTimeoutError=False
+            logTimeoutError=False,
         )
 
         # This is not a lambda, so that it can have a breakpoint
@@ -116,39 +143,46 @@ class TupleActionProcessorProxy:
 
         pr.addCallback(reply)
 
-        pr.addCallback(lambda _: logger.debug("Received action response from server"))
+        pr.addCallback(
+            lambda _: logger.debug("Received action response from server")
+        )
         pr.addErrback(self.__handlePrFailure, payloadEnvelope, sendResponse)
 
         vortexMsg = yield payloadEnvelope.toVortexMsgDefer()
         try:
-            yield VortexFactory.sendVortexMsg(vortexMsgs=vortexMsg,
-                                              destVortexName=self._proxyToVortexName)
+            yield VortexFactory.sendVortexMsg(
+                vortexMsgs=vortexMsg, destVortexName=self._proxyToVortexName
+            )
         except Exception as e:
             logger.exception(e)
 
     @inlineCallbacks
-    def __handlePrFailure(self, f: Failure,
-                          payloadEnvelope: PayloadEnvelope,
-                          sendResponse: SendVortexMsgResponseCallable):
+    def __handlePrFailure(
+        self,
+        f: Failure,
+        payloadEnvelope: PayloadEnvelope,
+        sendResponse: SendVortexMsgResponseCallable,
+    ):
         payload = yield payloadEnvelope.decodePayloadDefer()
         action = payload.tuples[0]
         if f.check(TimeoutError):
             logger.error(
                 "Received no response from\nprocessor %s\naction %s",
                 self._filt,
-                action
+                action,
             )
         else:
             logger.error(
                 "Unexpected error, %s\nprocessor %s\naction %s",
                 f,
                 self._filt,
-                action
+                action,
             )
 
         vortexLogFailure(f, logger)
 
-        vortexMsg = yield PayloadEnvelope(filt=payloadEnvelope.filt,
-                                          result=str(f.value)).toVortexMsgDefer()
+        vortexMsg = yield PayloadEnvelope(
+            filt=payloadEnvelope.filt, result=str(f.value)
+        ).toVortexMsgDefer()
 
         sendResponse(vortexMsg)
